@@ -32,7 +32,7 @@ def describe(schema, selects=()):
 
 
 def select(schema, selects, index=0):
-    if selects in {("all",), ("",)}:
+    if selects in {("all",), ("",), ()}:
         return Result.ok(schema)
 
     if index < len(selects) - 1:
